@@ -1,5 +1,6 @@
 from dataclasses import dataclass, field
 from typing import Dict, TYPE_CHECKING
+from django.conf import settings as django_settings
 
 from px_settings.contrib.django import settings as s
 
@@ -29,9 +30,13 @@ class Settings:
         },
         'DEFAULT_SENDER': 'default',
         'CONFIRM_CODE_GENERATOR': 'wcd_2factor.services.confirmer.make_confirmation_code',
+        'DEBUG_CODE_RESPONSE': False,
     }
     ```
     """
+    _DEBUG_CODE_RESPONSE: bool = False
+    DEBUG_CODE_RESPONSE: bool = _DEBUG_CODE_RESPONSE
+
     SENDERS: Dict[str, 'SenderConfig'] = field(default_factory=dict)
     DEFAULT_SENDER: str = 'default'
     CACHE: str = 'default'
@@ -43,5 +48,13 @@ class Settings:
             for key, config in self.SENDERS.items()
         ]
 
+    @property
+    def DEBUG_CODE_RESPONSE(self) -> bool:
+        return self._DEBUG_CODE_RESPONSE and django_settings.DEBUG
+
+    @DEBUG_CODE_RESPONSE.setter
+    def DEBUG_CODE_RESPONSE(self, value: bool) -> None:
+        self._DEBUG_CODE_RESPONSE = value
+
 
 settings = Settings()
