@@ -4,6 +4,7 @@ from rest_framework import status
 from rest_framework.response import Response
 from django.db import transaction
 
+from wcd_2factor.conf import settings
 from .serializers import RequestConfirmationSerializer, ConfirmSerializer
 
 
@@ -14,13 +15,24 @@ __all__ = (
 
 
 class SerializerCommitterMixin:
+    def collect_response(self, request, state, **kwargs):
+        response = {'id': state.id}
+
+        if settings.DEBUG_CODE_RESPONSE:
+            response['code'] = state.code
+
+        return response
+
     @transaction.atomic()
     def post(self, request, **kwargs):
         serializer = self.get_serializer(data=request.data)
         serializer.is_valid(raise_exception=True)
         state = serializer.commit()
 
-        return Response({'id': state.id}, status=status.HTTP_200_OK)
+        return Response(
+            self.collect_response(request, serializer=serializer, state=state),
+            status=status.HTTP_200_OK,
+        )
 
 
 class RequestConfirmationView(SerializerCommitterMixin, GenericAPIView):
